Learn R Programming

corTESTsrd (version 1.0-0)

spearman_var_independent: Asymptotic variance of estimator of Spearman's Rho between independent iid random variables

Description

Calculates the asymptotic variance of the estimator of Spearman's Rho between iid observations of independent random variables. The expression comes from the asymptotic normal distribution of the estimator, see e.g. equation 3.13 in chapter 11 of Gibbons and Chakraborti (2003).

Usage

spearman_var_independent(n)

Value

Asymptotic variance of estimator.

Arguments

n

number of observations, should be integer bigger than 0.

References

J. D. Gibbons, and S. Chakraborti, Nonparametric statistical inference (4th Edition). CRC press, 2003.

Examples

Run this code
spearman_var_independent(n=50)

Run the code above in your browser using DataLab