kendall_var_independent: Asymptotic variance of estimator of Kendall's Tau between independent iid random variables
Description
Calculates the asymptotic variance of the estimator of Kendall's Tau between iid observations
of independent random variables. The expression comes from the asymptotic normal distribution of the estimator,
see e.g. equation 2.30 in chapter 11 of Gibbons and Chakraborti (2003).
Usage
kendall_var_independent(n)
Value
Asymptotic variance of estimator.
Arguments
n
number of observations, should be integer bigger than 0.
References
J. D. Gibbons, and S. Chakraborti, Nonparametric statistical inference (4th Edition). CRC press, 2003.